Division class

Constructors

Division({required String id, required String name, required String bnName, required String lat, required String long})
Division.fromJson(Map<String, dynamic> json)
factory

Properties

bnName String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lat String
final
long String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited